import sys


def print_lol(the_list, indent=False, level=0, fn=sys.out):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, indent, level + 1, fn)
        else:
            if indent:
                for tab_stop in range(level):  # 次for循环可替换代码为print('\t'*level,end='')1.3.1
                    print('\t', end='', file=fn)
            print(each_item, file=fn)
