from distutils.core import setup

setup(
    name='nester_ht7714',
    version='2.3.1',
    py_modules=['nester'],
    author='hfpython',
    author_email='hfpython@headfirstlabs.com',
    url='http://www.headfirstlabs.com',
    description='A simple printer of nested lists,更新了写入文件',

)
